@@ -69,8 +69,7 @@
   and assignments are always by value (i.e. strings are copied):
   * ast_string_field_set() stores a simple value;
   * ast_string_field_build() builds the string using a printf-style format;
-  * ast_string_field_build_va() is the varargs version of the above (for
-    portability reasons it uses two vararg arguments);
+  * ast_string_field_build_va() is the varargs version of the above;
   * variants of these function allow passing a pointer to the field
     as an argument.
 
@@ -82,8 +81,8 @@
   ast_string_field_build(x, blah, "%d %s", zipcode, city);
   ast_string_field_ptr_build(x, &x->blah, "%d %s", zipcode, city);
 
-  ast_string_field_build_va(x, bar, fmt, args1, args2)
-  ast_string_field_ptr_build_va(x, &x->bar, fmt, args1, args2)
+  ast_string_field_build_va(x, bar, fmt, args)
+  ast_string_field_ptr_build_va(x, &x->bar, fmt, args)
   \endcode
 
   When the structure instance is no longer needed, the fields
@@ -206,12 +205,11 @@ void __ast_string_field_ptr_build(struct ast_string_field_mgr *mgr,
   \param ptr Pointer to a field within the structure
   \param format printf-style format string
   \param args va_list of the args for the format_string
-  \param args_again a copy of the first va_list for the sake of bsd not having a copy routine
   \return nothing
 */
 void __ast_string_field_ptr_build_va(struct ast_string_field_mgr *mgr,
 				     struct ast_string_field_pool **pool_head,
-				     ast_string_field *ptr, const char *format, va_list a1, va_list a2) __attribute__((format(printf, 4, 0)));
+				     ast_string_field *ptr, const char *format, va_list ap) __attribute__((format(printf, 4, 0)));
 
 /*!
   \brief Declare a string field
@@ -370,23 +368,21 @@ void __ast_string_field_release_active(struct ast_string_field_pool *pool_head,
   \param x Pointer to a structure containing fields
   \param ptr Pointer to a field within the structure
   \param fmt printf-style format string
-  \param args1 Arguments for format string in va_list format
-  \param args2 a second copy of the va_list for the sake of bsd, with no va_list copy operation
+  \param args Arguments for format string in va_list format
   \return nothing
 */
-#define ast_string_field_ptr_build_va(x, ptr, fmt, args1, args2) \
-	__ast_string_field_ptr_build_va(&(x)->__field_mgr, &(x)->__field_mgr_pool, (ast_string_field *) ptr, fmt, args1, args2)
+#define ast_string_field_ptr_build_va(x, ptr, fmt, args) \
+	__ast_string_field_ptr_build_va(&(x)->__field_mgr, &(x)->__field_mgr_pool, (ast_string_field *) ptr, fmt, args)
 
 /*!
   \brief Set a field to a complex (built) value
   \param x Pointer to a structure containing fields
   \param field Name of the field to set
   \param fmt printf-style format string
-  \param args1 argument one
-  \param args2 argument two
+  \param args Arguments for format string in va_list format
   \return nothing
 */
-#define ast_string_field_build_va(x, field, fmt, args1, args2) \
-	__ast_string_field_ptr_build_va(&(x)->__field_mgr, &(x)->__field_mgr_pool, (ast_string_field *) &(x)->field, fmt, args1, args2)
+#define ast_string_field_build_va(x, field, fmt, args) \
+	__ast_string_field_ptr_build_va(&(x)->__field_mgr, &(x)->__field_mgr_pool, (ast_string_field *) &(x)->field, fmt, args)
 
 #endif /* _ASTERISK_STRINGFIELDS_H */
